@@ -249,4 +249,8 @@ public class Image extends Misc {
 	native static final protected void gtk_image_get_icon_name(Handle image, String iconName, int[] size);
 	native static final protected int gtk_image_get_pixel_size(Handle image);
 
+    /* Deprecated functions.
+    native static final private void gtk_image_set(Handle image, Handle val, Handle mask);
+    native static final private void gtk_image_get(Handle image, Handle val, Handle mask);
+    */
 }
