@@ -13,6 +13,7 @@ import java.util.Vector;
 import org.gnu.glib.EventMap;
 import org.gnu.glib.EventType;
 import org.gnu.glib.GObject;
+import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 import org.gnu.gtk.event.SpinEvent;
 import org.gnu.gtk.event.SpinListener;
@@ -52,7 +53,7 @@ public class SpinButton extends Entry {
 	/**
 	 * Construct a new SpinButton from a handle to a native resource.
 	 */
-	public SpinButton(int handle) {
+	public SpinButton(Handle handle) {
 		super(handle);
 	}
 
@@ -81,8 +82,8 @@ public class SpinButton extends Entry {
 	 * @return the adjustment object for this SpinButton
 	 */
 	public Adjustment getAdjustment() {
-		int hndl = gtk_spin_button_get_adjustment(getHandle());
-		GObject obj = retrieveGObject(hndl);
+	    Handle hndl = gtk_spin_button_get_adjustment(getHandle());
+		GObject obj = getGObjectFromHandle(hndl);
 		if (null != obj)
 			return (Adjustment)obj;
 		return new Adjustment(hndl);
@@ -270,39 +271,29 @@ public class SpinButton extends Entry {
 		return new Type(gtk_spin_button_get_type());
 	}
 
-	/****************************************
-	 * BEGINNING OF GENERATED CODE
-	 ****************************************/
 	native static final protected int gtk_spin_button_get_type();
-	native static final protected void gtk_spin_button_configure(
-		int spin_button,
-		int adjustment,
-		double climbRate,
-		int digits);
-	native static final protected int gtk_spin_button_new(int adjustment, double climbRate, int digits);
-	native static final protected int gtk_spin_button_new_with_range(double min, double max, double step);
-	native static final protected void gtk_spin_button_set_adjustment(int spin_button, int adjustment);
-	native static final protected int gtk_spin_button_get_adjustment(int spin_button);
-	native static final protected void gtk_spin_button_set_digits(int spin_button, int digits);
-	native static final protected int gtk_spin_button_get_digits(int spin_button);
-	native static final protected void gtk_spin_button_set_increments(int spin_button, double step, double page);
-	native static final protected void gtk_spin_button_get_increments(int spin_button, double[] step, double[] page);
-	native static final protected void gtk_spin_button_set_range(int spin_button, double min, double max);
-	native static final protected void gtk_spin_button_get_range(int spin_button, double[] min, double[] max);
-	native static final protected double gtk_spin_button_get_value(int spin_button);
-	native static final protected int gtk_spin_button_get_value_as_int(int spin_button);
-	native static final protected void gtk_spin_button_set_value(int spin_button, double value);
-	native static final protected void gtk_spin_button_set_update_policy(int spin_button, int policy);
-	native static final protected int gtk_spin_button_get_update_policy(int spin_button);
-	native static final protected void gtk_spin_button_set_numeric(int spin_button, boolean numeric);
-	native static final protected boolean gtk_spin_button_get_numeric(int spin_button);
-	native static final protected void gtk_spin_button_spin(int spin_button, int direction, double increment);
-	native static final protected void gtk_spin_button_set_wrap(int spin_button, boolean wrap);
-	native static final protected boolean gtk_spin_button_get_wrap(int spin_button);
-	native static final protected void gtk_spin_button_set_snap_to_ticks(int spin_button, boolean snapToTicks);
-	native static final protected boolean gtk_spin_button_get_snap_to_ticks(int spin_button);
-	native static final protected void gtk_spin_button_update(int spin_button);
-	/****************************************
-	 * END OF GENERATED CODE
-	 ****************************************/
+	native static final protected void gtk_spin_button_configure(Handle spin_button,Handle adjustment,double climbRate,int digits);
+	native static final protected Handle gtk_spin_button_new(Handle adjustment, double climbRate, int digits);
+	native static final protected Handle gtk_spin_button_new_with_range(double min, double max, double step);
+	native static final protected void gtk_spin_button_set_adjustment(Handle spin_button, Handle adjustment);
+	native static final protected Handle gtk_spin_button_get_adjustment(Handle spin_button);
+	native static final protected void gtk_spin_button_set_digits(Handle spin_button, int digits);
+	native static final protected int gtk_spin_button_get_digits(Handle spin_button);
+	native static final protected void gtk_spin_button_set_increments(Handle spin_button, double step, double page);
+	native static final protected void gtk_spin_button_get_increments(Handle spin_button, double[] step, double[] page);
+	native static final protected void gtk_spin_button_set_range(Handle spin_button, double min, double max);
+	native static final protected void gtk_spin_button_get_range(Handle spin_button, double[] min, double[] max);
+	native static final protected double gtk_spin_button_get_value(Handle spin_button);
+	native static final protected int gtk_spin_button_get_value_as_int(Handle spin_button);
+	native static final protected void gtk_spin_button_set_value(Handle spin_button, double value);
+	native static final protected void gtk_spin_button_set_update_policy(Handle spin_button, int policy);
+	native static final protected int gtk_spin_button_get_update_policy(Handle spin_button);
+	native static final protected void gtk_spin_button_set_numeric(Handle spin_button, boolean numeric);
+	native static final protected boolean gtk_spin_button_get_numeric(Handle spin_button);
+	native static final protected void gtk_spin_button_spin(Handle spin_button, int direction, double increment);
+	native static final protected void gtk_spin_button_set_wrap(Handle spin_button, boolean wrap);
+	native static final protected boolean gtk_spin_button_get_wrap(Handle spin_button);
+	native static final protected void gtk_spin_button_set_snap_to_ticks(Handle spin_button, boolean snapToTicks);
+	native static final protected boolean gtk_spin_button_get_snap_to_ticks(Handle spin_button);
+	native static final protected void gtk_spin_button_update(Handle spin_button);
 }
