@@ -12,8 +12,9 @@ import org.gnu.glib.Boxed;
 import org.gnu.glib.Handle;
 
 /**
- * A path refers to a single row in a {@link TreeStore}. In this respect, it is
- * similar to a {@link TreeIter}, however a path also contains details of the
+ * A path refers to a single row in a {@link TreeModel} (such as a 
+ * {@link ListStore} or a {@link TreeStore}). In this respect, it is similar
+ * to a {@link TreeIter}, however a path also contains details of the
  * structure of the tree (TreeIter is a generic object for the entire TreeView
  * family, including flat lists and tables.)
  */
@@ -23,14 +24,14 @@ public class TreePath extends Boxed
 	 * Construct path from native handle
 	 */
 	protected TreePath(Handle handle){
-		this.handle = handle;
+		super(handle);
 	}
 
 	/**
 	 * Constructs a new path.
 	 */
 	public TreePath(){
-		handle = gtk_tree_path_new ();
+		super(gtk_tree_path_new ());
 	}
 
 	/**
@@ -42,7 +43,7 @@ public class TreePath extends Boxed
 	 * TODO: throw an exception on null response.
 	 */
 	public TreePath(String path){
-		handle = gtk_tree_path_new_from_string(path);
+		super(gtk_tree_path_new_from_string(path));
 	}
 
 	/**
@@ -52,14 +53,14 @@ public class TreePath extends Boxed
 	 * @return String representation of the path.
 	 */
 	public String toString(){
-		return gtk_tree_path_to_string(handle);
+		return gtk_tree_path_to_string(getHandle());
 	}
 
 	/**
 	 * Returns the current depth of path.
 	 */
 	public int getDepth(){
-		return gtk_tree_path_get_depth(handle);
+		return gtk_tree_path_get_depth(getHandle());
 	}
 
 	/**
@@ -72,14 +73,14 @@ public class TreePath extends Boxed
 	 * then 1 is returned. If the two nodes are equal, then 0 is returned.
 	 */
 	public int compare(TreePath other){
-		return gtk_tree_path_compare(other.getHandle(), handle);
+		return gtk_tree_path_compare(other.getHandle(), getHandle());
 	}
 
 	/**
 	 * Moves the path to point to the next node at the current depth.
 	 */
 	public void next(){
-		 gtk_tree_path_next(handle);
+		 gtk_tree_path_next(getHandle());
 	}
 
 	/**
@@ -88,7 +89,7 @@ public class TreePath extends Boxed
 	 * @return TRUE if path has a previous node, and the move was made.
 	 */
 	public boolean previous(){
-		return	gtk_tree_path_prev(handle);
+		return	gtk_tree_path_prev(getHandle());
 	}
 
 	/**
@@ -96,14 +97,14 @@ public class TreePath extends Boxed
 	 * @return TRUE if path has a parent, and the move was made.
 	 */
 	public boolean up(){
-		return gtk_tree_path_up(handle);
+		return gtk_tree_path_up(getHandle());
 	}
 
 	/**
 	 * Moves path to point to the first child of the current path.
 	 */
 	public void down(){
-		gtk_tree_path_down(handle);
+		gtk_tree_path_down(getHandle());
 	}
 
 	/**
@@ -112,7 +113,7 @@ public class TreePath extends Boxed
 	 * @return TRUE if descendant is contained inside path
 	 */
 	public boolean isAncestor(TreePath descendant){
-		return gtk_tree_path_is_ancestor(handle, descendant.getHandle());
+		return gtk_tree_path_is_ancestor(getHandle(), descendant.getHandle());
 	}
 
 	/**
@@ -121,7 +122,7 @@ public class TreePath extends Boxed
 	 * @return TRUE if ancestor contains path somewhere below it
 	 */
 	public boolean isDescendant(TreePath ancestor){
-		return gtk_tree_path_is_descendant(handle, ancestor.getHandle());
+		return gtk_tree_path_is_descendant(getHandle(), ancestor.getHandle());
 	}
 	
 	/**
@@ -130,7 +131,7 @@ public class TreePath extends Boxed
 	 * @param index
 	 */
 	public void appendIndex(int index) {
-		gtk_tree_path_append_index(handle, index);
+		gtk_tree_path_append_index(getHandle(), index);
 	}
 	
 	/**
@@ -139,7 +140,7 @@ public class TreePath extends Boxed
 	 * @param index
 	 */
 	public void prependIndex(int index) {
-		gtk_tree_path_prepend_index(handle, index);
+		gtk_tree_path_prepend_index(getHandle(), index);
 	}
 	
 	/**
@@ -147,7 +148,7 @@ public class TreePath extends Boxed
 	 * @return  An array of ints, each representing a node in the tree.
 	 */
 	public int[] getIndices() {
-		return gtk_tree_path_get_indices(handle);
+		return gtk_tree_path_get_indices(getHandle());
 	}
 
 
